## 1.4.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 1.4.0.1 (2023-12-11)

fanstatic: Use `Unpack` in `fanstatic.injector.Injector` (#11139)

## 1.4.0.0 (2023-11-22)

Add stubs for fanstatic (#9931)

